import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bake_all(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
             undo: typing.Optional[bool] = None):
    ''' Bake Entire Fluid Simulation

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def bake_data(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None):
    ''' Bake Fluid Data

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def bake_guides(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None):
    ''' Bake Fluid Guiding

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def bake_mesh(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None):
    ''' Bake Fluid Mesh

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def bake_noise(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Bake Fluid Noise

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def bake_particles(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None):
    ''' Bake Fluid Particles

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_all(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
             undo: typing.Optional[bool] = None):
    ''' Free Entire Fluid Simulation

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_data(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None):
    ''' Free Fluid Data

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_guides(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None):
    ''' Free Fluid Guiding

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_mesh(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None):
    ''' Free Fluid Mesh

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_noise(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Free Fluid Noise

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def free_particles(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None):
    ''' Free Fluid Particles

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def pause_bake(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Pause Bake

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def preset_add(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None,
               *,
               name: typing.Union[str, typing.Any] = "",
               remove_name: typing.Union[bool, typing.Any] = False,
               remove_active: typing.Union[bool, typing.Any] = False):
    ''' Add or remove a Fluid Preset

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the preset, used to make the path name
    :type name: typing.Union[str, typing.Any]
    :param remove_name: remove_name
    :type remove_name: typing.Union[bool, typing.Any]
    :param remove_active: remove_active
    :type remove_active: typing.Union[bool, typing.Any]
    '''

    pass



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class InfoFunctionRNA:
    args = None
    ''' '''

    bl_func = None
    ''' '''

    description = None
    ''' '''

    global_lookup = None
    ''' '''

    identifier = None
    ''' '''

    is_classmethod = None
    ''' '''

    return_values = None
    ''' '''

    def build(self):
        ''' 

        '''
        pass


class InfoOperatorRNA:
    args = None
    ''' '''

    bl_op = None
    ''' '''

    description = None
    ''' '''

    func_name = None
    ''' '''

    global_lookup = None
    ''' '''

    identifier = None
    ''' '''

    module_name = None
    ''' '''

    name = None
    ''' '''

    def build(self):
        ''' 

        '''
        pass

    def get_location(self):
        ''' 

        '''
        pass


class InfoPropertyRNA:
    array_dimensions = None
    ''' '''

    array_length = None
    ''' '''

    bl_prop = None
    ''' '''

    collection_type = None
    ''' '''

    default = None
    ''' '''

    default_str = None
    ''' '''

    description = None
    ''' '''

    enum_items = None
    ''' '''

    enum_pointer = None
    ''' '''

    fixed_type = None
    ''' '''

    global_lookup = None
    ''' '''

    identifier = None
    ''' '''

    is_argument_optional = None
    ''' '''

    is_enum_flag = None
    ''' '''

    is_never_none = None
    ''' '''

    is_readonly = None
    ''' '''

    is_required = None
    ''' '''

    max = None
    ''' '''

    min = None
    ''' '''

    name = None
    ''' '''

    srna = None
    ''' '''

    subtype = None
    ''' '''

    type = None
    ''' '''

    def build(self):
        ''' 

        '''
        pass

    def get_arg_default(self, force):
        ''' 

        '''
        pass

    def get_type_description(self, as_ret, as_arg, class_fmt, mathutils_fmt,
                             collection_id, enum_descr_override):
        ''' 

        '''
        pass


class InfoStructRNA:
    base = None
    ''' '''

    bl_rna = None
    ''' '''

    children = None
    ''' '''

    description = None
    ''' '''

    full_path = None
    ''' '''

    functions = None
    ''' '''

    global_lookup = None
    ''' '''

    identifier = None
    ''' '''

    module_name = None
    ''' '''

    name = None
    ''' '''

    nested = None
    ''' '''

    properties = None
    ''' '''

    py_class = None
    ''' '''

    references = None
    ''' '''

    def build(self):
        ''' 

        '''
        pass

    def get_bases(self):
        ''' 

        '''
        pass

    def get_nested_properties(self, ls):
        ''' 

        '''
        pass

    def get_py_c_functions(self):
        ''' 

        '''
        pass

    def get_py_c_properties_getset(self):
        ''' 

        '''
        pass

    def get_py_functions(self):
        ''' 

        '''
        pass

    def get_py_properties(self):
        ''' 

        '''
        pass


def BuildRNAInfo():
    ''' 

    '''

    pass


def GetInfoFunctionRNA(bl_rna, parent_id):
    ''' 

    '''

    pass


def GetInfoOperatorRNA(bl_rna):
    ''' 

    '''

    pass


def GetInfoPropertyRNA(bl_rna, parent_id):
    ''' 

    '''

    pass


def GetInfoStructRNA(bl_rna):
    ''' 

    '''

    pass


def float_as_string(f):
    ''' 

    '''

    pass


def get_direct_functions(rna_type):
    ''' 

    '''

    pass


def get_direct_properties(rna_type):
    ''' 

    '''

    pass


def get_py_class_from_rna(rna_type):
    ''' 

    '''

    pass


def main():
    ''' 

    '''

    pass


def range_str(val):
    ''' 

    '''

    pass


def rna_id_ignore(rna_id):
    ''' 

    '''

    pass



import sys
import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")


class ToolActivePanelHelper:
    bl_label = None
    ''' '''

    def draw(self, context):
        ''' 

        '''
        pass


class ToolDef:
    cursor = None
    ''' '''

    data_block = None
    ''' '''

    description = None
    ''' '''

    draw_cursor = None
    ''' '''

    draw_settings = None
    ''' '''

    icon = None
    ''' '''

    idname = None
    ''' '''

    keymap = None
    ''' '''

    label = None
    ''' '''

    operator = None
    ''' '''

    options = None
    ''' '''

    widget = None
    ''' '''

    widget_properties = None
    ''' '''

    def count(self, value):
        ''' 

        '''
        pass

    def from_dict(self, kw_args):
        ''' 

        '''
        pass

    def from_fn(self, fn):
        ''' 

        '''
        pass

    def index(self, value, start, stop):
        ''' 

        '''
        pass


class ToolSelectPanelHelper:
    def draw(self, context):
        ''' 

        '''
        pass

    def draw_active_tool_fallback(self, context, layout, tool,
                                  is_horizontal_layout):
        ''' 

        '''
        pass

    def draw_active_tool_header(self, context, layout, show_tool_icon_always,
                                tool_key):
        ''' 

        '''
        pass

    def draw_cls(self, layout, context, detect_layout, scale_y):
        ''' 

        '''
        pass

    def draw_fallback_tool_items(self, layout, context):
        ''' 

        '''
        pass

    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
        ''' 

        '''
        pass

    def keymap_ui_hierarchy(self, context_mode):
        ''' 

        '''
        pass

    def register(self):
        ''' 

        '''
        pass

    def tool_active_from_context(self, context):
        ''' 

        '''
        pass

    def tools_all(self):
        ''' 

        '''
        pass

    def tools_from_context(self, context, mode):
        ''' 

        '''
        pass


class WM_MT_toolsystem_submenu(bpy_types.Menu, bpy_types._GenericUI):
    bl_label = None
    ''' '''

    bl_rna = None
    ''' '''

    id_data = None
    ''' '''

    def append(self, draw_func):
        ''' 

        '''
        pass

    def as_pointer(self):
        ''' 

        '''
        pass

    def bl_rna_get_subclass(self):
        ''' 

        '''
        pass

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        pass

    def draw(self, context):
        ''' 

        '''
        pass

    def draw_collapsible(self, context, layout):
        ''' 

        '''
        pass

    def draw_preset(self, _context):
        ''' 

        '''
        pass

    def driver_add(self):
        ''' 

        '''
        pass

    def driver_remove(self):
        ''' 

        '''
        pass

    def get(self):
        ''' 

        '''
        pass

    def id_properties_clear(self):
        ''' 

        '''
        pass

    def id_properties_ensure(self):
        ''' 

        '''
        pass

    def id_properties_ui(self):
        ''' 

        '''
        pass

    def is_extended(self):
        ''' 

        '''
        pass

    def is_property_hidden(self):
        ''' 

        '''
        pass

    def is_property_overridable_library(self):
        ''' 

        '''
        pass

    def is_property_readonly(self):
        ''' 

        '''
        pass

    def is_property_set(self):
        ''' 

        '''
        pass

    def items(self):
        ''' 

        '''
        pass

    def keyframe_delete(self):
        ''' 

        '''
        pass

    def keyframe_insert(self):
        ''' 

        '''
        pass

    def keys(self):
        ''' 

        '''
        pass

    def path_from_id(self):
        ''' 

        '''
        pass

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name, add_operator):
        ''' 

        '''
        pass

    def path_resolve(self):
        ''' 

        '''
        pass

    def pop(self):
        ''' 

        '''
        pass

    def prepend(self, draw_func):
        ''' 

        '''
        pass

    def property_overridable_library_set(self):
        ''' 

        '''
        pass

    def property_unset(self):
        ''' 

        '''
        pass

    def remove(self, draw_func):
        ''' 

        '''
        pass

    def type_recast(self):
        ''' 

        '''
        pass

    def values(self):
        ''' 

        '''
        pass


def activate_by_id(context, space_type, idname, as_fallback):
    ''' 

    '''

    pass


def activate_by_id_or_cycle(context, space_type, idname, offset, as_fallback):
    ''' 

    '''

    pass


def description_from_id(context, space_type, idname, use_operator):
    ''' 

    '''

    pass


def item_from_flat_index(context, space_type, index):
    ''' 

    '''

    pass


def item_from_id(context, space_type, idname):
    ''' 

    '''

    pass


def item_from_id_active(context, space_type, idname):
    ''' 

    '''

    pass


def item_from_id_active_with_group(context, space_type, idname):
    ''' 

    '''

    pass


def item_from_index_active(context, space_type, index):
    ''' 

    '''

    pass


def item_group_from_id(context, space_type, idname, coerce):
    ''' 

    '''

    pass


def keymap_from_id(context, space_type, idname):
    ''' 

    '''

    pass



import sys
import typing
from . import node_utils
from . import anim_utils
from . import image_utils
from . import mesh_utils
from . import io_utils
from . import keyconfig_utils
from . import object_utils
from . import id_map_utils
from . import view3d_utils
from . import asset_utils
from . import bmesh_utils
from . import node_shader_utils
from . import wm_utils

GenericType = typing.TypeVar("GenericType")
